@@ -53,7 +53,7 @@ void SsidComboBox::init(const QString &ssid)
 {
     m_initialSsid = ssid;
 
-    // qCDebug(PLASMA_NM) << "Initial ssid:" << m_initialSsid;
+    // qCDebug(PLASMA_NM_EDITOR_LOG) << "Initial ssid:" << m_initialSsid;
 
     QList<NetworkManager::WirelessNetwork::Ptr> networks;
 
@@ -113,7 +113,7 @@ void SsidComboBox::addSsidsToCombo(const QList<NetworkManager::WirelessNetwork::
             continue;
         }
 
-        for (const NetworkManager::WirelessDevice::Ptr &wifiDev : wifiDevices) {
+        for (const NetworkManager::WirelessDevice::Ptr &wifiDev : qAsConst(wifiDevices)) {
             if (wifiDev->findNetwork(network->ssid()) == network) {
                 if (!empty) {
                     insertSeparator(count());
